Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2358)

Unified Diff: chrome/browser/policy/policy_status_info.h

Issue 9111022: Removed ConfigurationPolicyType and extended PolicyMap. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/policy/policy_map_unittest.cc ('k') | chrome/browser/policy/policy_status_info.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/policy/policy_status_info.h
diff --git a/chrome/browser/policy/policy_status_info.h b/chrome/browser/policy/policy_status_info.h
index 3620392cc46742686cd8c9776426c6d6639fc1b9..2327033c1e8628bc75535d436b835a712b5a1d45 100644
--- a/chrome/browser/policy/policy_status_info.h
+++ b/chrome/browser/policy/policy_status_info.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -9,26 +9,13 @@
#include "base/memory/scoped_ptr.h"
#include "base/string16.h"
#include "base/values.h"
+#include "chrome/browser/policy/policy_map.h"
namespace policy {
// Describes a policy's status on the client.
struct PolicyStatusInfo {
- // Defines the possible sources a policy can have.
- enum PolicySourceType {
- USER,
- DEVICE,
- SOURCE_TYPE_UNDEFINED,
- };
-
- // Defines the possible levels a policy can be operating on.
- enum PolicyLevel {
- MANDATORY,
- RECOMMENDED,
- LEVEL_UNDEFINED,
- };
-
// Defines the possible statuses a policy can have.
enum PolicyStatus {
ENFORCED,
@@ -38,7 +25,7 @@ struct PolicyStatusInfo {
PolicyStatusInfo();
PolicyStatusInfo(const string16& name,
- PolicySourceType source_type,
+ PolicyScope scope,
PolicyLevel level,
Value* value,
PolicyStatus status,
@@ -53,9 +40,8 @@ struct PolicyStatusInfo {
// contents and false otherwise.
bool Equals(const PolicyStatusInfo* other_info) const;
- // Returns the string corresponding to the PolicySourceType enum value
- // |source_type|.
- static string16 GetSourceTypeString(PolicySourceType source_type);
+ // Returns the string corresponding to the PolicyScope enum value |scope|.
+ static string16 GetPolicyScopeString(PolicyScope scope);
// Returns the string corresponding to the PolicyLevel enum value |level|.
static string16 GetPolicyLevelString(PolicyLevel level);
@@ -63,10 +49,10 @@ struct PolicyStatusInfo {
// The name of the policy.
string16 name;
- // The source type of the policy (user, device or undefined).
- PolicySourceType source_type;
+ // The scope of the policy (user or device).
+ PolicyScope scope;
- // The level of the policy (mandatory, recommended or undefined).
+ // The level of the policy (mandatory or recommended).
PolicyLevel level;
// The policy value.
@@ -81,8 +67,8 @@ struct PolicyStatusInfo {
// Paths for the DictionaryValue returned by GetDictionaryValue().
static const char kLevelDictPath[];
static const char kNameDictPath[];
+ static const char kScopeDictPath[];
static const char kSetDictPath[];
- static const char kSourceTypeDictPath[];
static const char kStatusDictPath[];
static const char kValueDictPath[];
« no previous file with comments | « chrome/browser/policy/policy_map_unittest.cc ('k') | chrome/browser/policy/policy_status_info.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698